# CraftBeerPi UI 

After installation the plugin UI is available under to following url
http://localhost:8080/cbpi_ui/static/index.html#

# Build Web App

npm start 
npm run build

# Install Plugin for Development

python3 setup.py develop

# Package Plugin 

python3 setup.py sdist